@@ -6,16 +6,13 @@ codestreams.
 
 # The number of lines in the module is long and that's ok.  It would not help
 # matters to move anything out to another file.
-# pylint: disable=C0302
 
 # "Too many instance attributes", "Too many arguments"
 # Some segments just have a lot of information.
 # It doesn't make sense to subclass just for that.
-# pylint: disable=R0902,R0913
 
 # "Too few public methods"  Some segments don't define any new methods from
 # the base Segment class.
-# pylint: disable=R0903
 
 import math
 import struct
@@ -24,23 +21,22 @@ import warnings
 
 import numpy as np
 
-from .core import LRCP, RLCP, RPCL, PCRL, CPRL
-from .core import WAVELET_XFORM_9X7_IRREVERSIBLE
-from .core import WAVELET_XFORM_5X3_REVERSIBLE
-from .core import _Keydefaultdict
+from .core import (LRCP, RLCP, RPCL, PCRL, CPRL,
+                   WAVELET_XFORM_9X7_IRREVERSIBLE,
+                   WAVELET_XFORM_5X3_REVERSIBLE,
+                   _Keydefaultdict)
 from .lib import openjp2 as opj2
 
 _factory = lambda x:  '{0} (invalid)'.format(x)
-_PROGRESSION_ORDER_DISPLAY = _Keydefaultdict(_factory,
-        { LRCP: 'LRCP',
-          RLCP: 'RLCP',
-          RPCL: 'RPCL',
-          PCRL: 'PCRL',
-          CPRL: 'CPRL'})
+_PROGRESSION_ORDER_DISPLAY = _Keydefaultdict(_factory, {LRCP: 'LRCP',
+                                                        RLCP: 'RLCP',
+                                                        RPCL: 'RPCL',
+                                                        PCRL: 'PCRL',
+                                                        CPRL: 'CPRL'})
 
-_WAVELET_TRANSFORM_DISPLAY = _Keydefaultdict(_factory,
-        { WAVELET_XFORM_9X7_IRREVERSIBLE: '9-7 irreversible',
-          WAVELET_XFORM_5X3_REVERSIBLE: '5-3 reversible'})
+_keysvalues = {WAVELET_XFORM_9X7_IRREVERSIBLE: '9-7 irreversible',
+               WAVELET_XFORM_5X3_REVERSIBLE: '5-3 reversible'}
+_WAVELET_TRANSFORM_DISPLAY = _Keydefaultdict(_factory, _keysvalues)
 
 _NO_PROFILE = 0
 _PROFILE_0 = 1
@@ -51,12 +47,11 @@ _PROFILE_4 = 4
 _KNOWN_PROFILES = [_NO_PROFILE, _PROFILE_0, _PROFILE_1, _PROFILE_3, _PROFILE_4]
 
 # How to display the codestream profile.
-_CAPABILITIES_DISPLAY = _Keydefaultdict(_factory,
-        { _NO_PROFILE: 'no profile',
-          _PROFILE_0: '0',
-          _PROFILE_1: '1',
-          _PROFILE_3: 'Cinema 2K',
-          _PROFILE_4: 'Cinema 4K'} )
+_CAPABILITIES_DISPLAY = _Keydefaultdict(_factory, {_NO_PROFILE: 'no profile',
+                                                   _PROFILE_0: '0',
+                                                   _PROFILE_1: '1',
+                                                   _PROFILE_3: 'Cinema 2K',
+                                                   _PROFILE_4: 'Cinema 4K'})
 
 # Need a catch-all list of valid markers.
 # See table A-1 in ISO/IEC FCD15444-1.
@@ -202,7 +197,7 @@ class Codestream(object):
                 msg = 'Invalid marker id encountered at byte {0:d} '
                 msg += 'in codestream:  "0x{1:x}"'
                 msg = msg.format(self._offset, self._marker_id)
-                warnings.warn(msg)
+                warnings.warn(msg, UserWarning)
                 break
 
             self.segment.append(segment)
@@ -298,7 +293,6 @@ class Codestream(object):
             msg += ''.join(strs)
         return msg
 
-    # pylint: disable=R0201
     def _parse_cme_segment(self, fptr):
         """Parse the CME marker segment.
 
@@ -642,7 +636,7 @@ class Codestream(object):
         srgn = data[1]
         sprgn = data[2]
 
-        return RGNsegment(length, offset, crgn, srgn, sprgn)
+        return RGNsegment(crgn, srgn, sprgn, length, offset)
 
     def _parse_siz_segment(self, fptr):
         """Parse the SIZ segment.
@@ -694,7 +688,7 @@ class Codestream(object):
         try:
             num_tiles_x = (xysiz[0] - xyosiz[0]) / (xytsiz[0] - xytosiz[0])
             num_tiles_y = (xysiz[1] - xyosiz[1]) / (xytsiz[1] - xytosiz[1])
-        except ZeroDivisionError as err:
+        except ZeroDivisionError:
             warnings.warn("Invalid tile dimensions.")
         else:
             numtiles = math.ceil(num_tiles_x) * math.ceil(num_tiles_y)
@@ -702,7 +696,6 @@ class Codestream(object):
                 msg = "Invalid number of tiles ({0}).".format(numtiles)
                 warnings.warn(msg)
 
-
         kwargs = {'rsiz': rsiz,
                   'xysiz': xysiz,
                   'xyosiz': xyosiz,
@@ -829,7 +822,6 @@ class Codestream(object):
 
         return TLMsegment(length, offset, ztlm, ttlm, ptlm)
 
-    # pylint: disable=W0613
     def _parse_reserved_marker(self, fptr):
         """Marker range between 0xff30 and 0xff39.
         """
@@ -1074,7 +1066,7 @@ class CMEsegment(Segment):
        15444-1:2004 - Information technology -- JPEG 2000 image coding system:
        Core coding system
     """
-    def __init__(self, rcme, ccme, length, offset):
+    def __init__(self, rcme, ccme, length=-1, offset=-1):
         Segment.__init__(self, marker_id='CME')
         self.rcme = rcme
         self.ccme = ccme
@@ -1463,7 +1455,7 @@ class RGNsegment(Segment):
        15444-1:2004 - Information technology -- JPEG 2000 image coding system:
        Core coding system
     """
-    def __init__(self, length, offset, crgn, srgn, sprgn):
+    def __init__(self, crgn, srgn, sprgn, length=-1, offset=-1):
         Segment.__init__(self, marker_id='RGN')
         self.length = length
         self.offset = offset
@@ -1613,6 +1605,7 @@ class SOCsegment(Segment):
         msg = "glymur.codestream.SOCsegment()"
         return msg
 
+
 class SODsegment(Segment):
     """Container for Start of Data (SOD) segment information.
 
@@ -1726,7 +1719,7 @@ class SOTsegment(Segment):
        15444-1:2004 - Information technology -- JPEG 2000 image coding system:
        Core coding system
     """
-    def __init__(self, isot, psot, tpsot, tnsot, length, offset):
+    def __init__(self, isot, psot, tpsot, tnsot, length=-1, offset=-1):
         Segment.__init__(self, marker_id='SOT')
         self.isot = isot
         self.psot = psot
