@@ -14,12 +14,11 @@ from distutils.version import LooseVersion
 import lxml.etree
 import numpy as np
 
-from .lib import openjpeg as opj
-from .lib import openjp2 as opj2
+from .lib import openjpeg as opj, openjp2 as opj2
 
 # Do not change the format of this next line!  Doing so risks breaking
 # setup.py
-version = "0.7.3"
+version = "0.8.0"
 _sv = LooseVersion(version)
 version_tuple = _sv.version
 
